from kafka import KafkaProducer, KafkaConsumer
from common.module import BaseUtil

logger = BaseUtil.set_logging('KafkaUtil')
config = BaseUtil.get_config()

kafka_config = config.read_config('kafka')
servers = str(config.read_config('kafka.servers')).split(',')
consumer_topic = str(config.read_config('kafka.consumer.topic'))
consumer_group_id = str(config.read_config('kafka.consumer.id'))


# 连接kafka
def producer_connect_kafka():
    logger.info("Connect to Kafka start")
    producer = KafkaProducer(bootstrap_servers=servers, key_serializer=str.encode, value_serializer=str.encode)
    logger.info("Connect to Kafka success")
    return producer


# 消费默认kafka
def consumer_connect_kafka():
    # 默认从最早一条消息进行消费
    logger.info("Connect to Kafka start")
    consumer = KafkaConsumer(consumer_topic, bootstrap_servers=servers, group_id=consumer_group_id)
    logger.info("Consumer connect to Kafka success")
    return consumer


# 消费kafka指定topic
def consumer_kafka(topic: str, group_id: str) -> KafkaConsumer:
    logger.info("Connect to Kafka start")
    consumer = KafkaConsumer(topic, bootstrap_servers=servers, group_id=group_id)
    logger.info("Consumer connect to Kafka success")
    return consumer



"""
配置信息 工具类
"""
import configparser
import yaml

file_type_dict = {
    'ini': 'ini',
    'yaml': 'yaml',
    'xml': 'xml'
}


class ConfigReader:

    def __init__(self, config_path, config_type):
        self.config_path: str = config_path
        self.config_type: str = config_type
        self.config_dict: dict = self.__load_config()

    def load_config_ini(self) -> dict:
        """读取配置文件-ini

        :return: dict格式的配置信息
        """
        # 创建配置文件并获取内容
        config = configparser.ConfigParser()
        config.read(self.config_path, encoding="utf-8")
        # 遍历配置文件组装配置信息字典
        config_dict = {}
        for section in config.sections():
            config_dict[section] = dict(config.items(section, raw=True))

        return config_dict

    def load_config_yaml(self) -> dict:
        """读取配置文件-yaml

        :return: dict格式的配置信息
        """
        # 读取文件，获取字符串格式的配置信息
        config_file = open(self.config_path, 'r', encoding='utf-8')
        config = config_file.read()
        # 用yaml.load()方法将配置转化为字典
        config_dict = yaml.load(config, Loader=yaml.FullLoader)

        return config_dict

    config_type_dict = {
        'ini': load_config_ini,
        'yaml': load_config_yaml
    }

    def __load_config(self):
        function = self.config_type_dict.get(self.config_type)
        return function(self)

    def read_config(self, item_path: str):
        """
        根据配置项路径获取配置信息

        :param item_path: 配置项路径，以英文句号.分隔
        :return: 根据具体配置内容，决定返回体的类型
        """
        item_path_list = item_path.split('.')
        config_dict = self.config_dict
        for item in item_path_list:
            config_dict = config_dict[item]

        config_item = config_dict
        return config_item



import re

# 正整数
number_pattern = "^\d*$"
# UTC时间格式
utc_time_format = '{}-{}-{}T{}:{}:{}.{}Z'
# YYYY-MM-DD hh:mm:ss
common_time_format = '{}-{}-{} {}:{}:{}'

if __name__ == '__main__':
    print(re.match(number_pattern, "0132132156"))




from time import strftime, localtime

# print(strftime('%Y-%m-%d %H:%M:%S', localtime(1650038400)))

format_second = "%d秒"
format_minute = "%d分%d秒"
format_hour = "%d时%d分%d秒"


def format_time_by_second(time_second: int):
    """
    根据输入的时间，格式化输出时间
    x时x分x秒

    :param time_second: 时间（单位：秒）
    :return:
    """
    if time_second:
        second = time_second % 60
        if second == time_second:
            # 秒
            return format_second % second
        else:
            minute = int((time_second / 60) % 60)
            if minute * 60 + second == time_second:
                # 分 秒
                return format_minute % (minute, second)
            else:
                # 时 分 秒
                hour = int(time_second / 60 / 60)
                return format_hour % (hour, minute, second)


if __name__ == '__main__':
    print(format_time_by_second(15))
    print(format_time_by_second(375))
    print(format_time_by_second(10552))



"""
字符串常用判断方法工具类
"""


def is_null(string: str) -> bool:
    return string is None


def is_not_null(string: str) -> bool:
    return string is not None


def is_blank(string: str) -> bool:
    return not bool(string)


def is_not_blank(string: str) -> bool:
    return bool(string)



import uuid
import time
import paho.mqtt.client as mqtt_client
from common.module import BaseUtil, StrUtil

logger = BaseUtil.set_logging('MqttUtil')
config = BaseUtil.get_config()

MQTT_ERR_SUCCESS = mqtt_client.MQTT_ERR_SUCCESS
MQTT_ERR_NO_CONN = mqtt_client.MQTT_ERR_NO_CONN
MQTT_ERR_QUEUE_SIZE = mqtt_client.MQTT_ERR_QUEUE_SIZE


class MqttClient:

    def __init__(self):
        self.client_id = f'python-mqtt-{uuid.uuid1().hex}'
        self.host = str(config.read_config('mqtt.host'))
        self.port = str(config.read_config('mqtt.port'))
        self.user = str(config.read_config('mqtt.user'))
        self.password = str(config.read_config('mqtt.password'))
        self.client = mqtt_client.Client(self.client_id)

    def connect_mqtt(self):
        if StrUtil.is_blank(self.host) or StrUtil.is_blank(self.port):
            logger.error('You must specify a host')

        try:
            logger.info('Try to connect host {} port {} '.format(self.host, self.port))
            if StrUtil.is_not_blank(self.user) or StrUtil.is_not_blank(self.password):
                self.client.username_pw_set(self.user, self.password)
            self.client.connect_async(self.host, int(self.port))
            self.client.loop_start()
            self.wait_for_connected(self.client)
        except Exception as e:
            logger.warning('Connect to MQTT Failed!')

    def on_disconnect(self, rc):
        logger.warning("Disconnected result code %s", rc)
        self.connect_mqtt()

    def on_connect(self, rc):
        if rc == 0:
            logger.info('Connected to MQTT Success, Host:%s, Port:%s', self.host, self.port)
            print("Connected to MQTT Broker!")
        else:
            print("Failed to connect, return code %d\n", rc)

    @staticmethod
    def wait_for_connected(client, time_out=5):
        count = 0
        logger.info("Connecting...... {} S  {}".format(count, client))
        while (not client.is_connected()) and (count < time_out):
            count += 1
            time.sleep(1)
            logger.info("Connecting...... %dS", count)



# !/usr/bin/python
# -*- coding: UTF-8 -*-
import pymysql

from common.module import BaseUtil

logger = BaseUtil.set_logging('DatabaseUtil')
config = BaseUtil.get_config()


# 连接mysql数据库
def connect_mysql() -> [pymysql, pymysql.cursors]:
    database = pymysql.connect(host=str(config.read_config('mysql.host')),
                               port=int(config.read_config('mysql.port')),
                               user=str(config.read_config('mysql.user')),
                               password=str(config.read_config('mysql.password')),
                               database=str(config.read_config('mysql.database')))
    logger.info("Connect to MySQL success")
    return [database, database.cursor()]
